==> rendition-11.32.1.tgz: package/dist_esm5/components/Filters/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import castArray from 'lodash/castArray';
import cloneDeep from 'lodash/cloneDeep';
import findIndex from 'lodash/findIndex';
import includes from 'lodash/includes';
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import map from 'lodash/map';
import reject from 'lodash/reject';
import * as React from 'react';
import FaClose from 'react-icons/lib/fa/close';
import FaFilter from 'react-icons/lib/fa/filter';
import styled from 'styled-components';
import { Button } from '../../';
import * as utils from '../../utils';
import { Box } from '../Box';
import { getDataModel } from '../DataTypes';
import { Flex } from '../Flex';
import Modal from '../Modal';
import Search from '../Search';
import Select from '../Select';
import Txt from '../Txt';
import * as SchemaSieve from './SchemaSieve';
import Summary from './Summary';
import ViewsMenu from './ViewsMenu';
var FilterInput = function (props) {
    var model = getDataModel(props.schema);
    if (!model) {
        return null;
    }
    var Edit = model.Edit;
    return (React.createElement(Edit, { schema: props.schema, value: props.value, operator: props.operator, onUpdate: props.onUpdate, slim: true }));
};
var RelativeBox = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var DeleteButton = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"], ["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"])));
var SearchWrapper = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tflex-basis: 500px;\n"], ["\n\tflex-basis: 500px;\n"])));
var FilterWrapper = styled(Box)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var Filters = (function (_super) {
    __extends(Filters, _super);
    function Filters(props) {
        var _this = _super.call(this, props) || this;
        _this.clearAllFilters = function () {
            _this.setFilters([]);
            _this.setState({
                searchString: '',
            });
        };
        var _a = _this.props, _b = _a.filters, filters = _b === void 0 ? [] : _b, schema = _a.schema, _c = _a.views, views = _c === void 0 ? [] : _c;
        var flatSchema = SchemaSieve.flattenSchema(schema);
        var flatViews = _this.flattenViews(views);
        var flatFilters = filters.map(function (filter) {
            return SchemaSieve.flattenSchema(filter);
        });
        _this.state = {
            showModal: false,
            searchString: '',
            editingFilter: null,
            filters: flatFilters,
            views: flatViews,
            schema: flatSchema,
            edit: [],
        };
        _this.state.edit.push(_this.getCleanEditModel());
        return _this;
    }
    Filters.prototype.componentDidUpdate = function (prevProps) {
        var newState = {};
        if (!isEqual(prevProps.schema, this.props.schema)) {
            newState.schema = SchemaSieve.flattenSchema(this.props.schema);
        }
        if (!isEqual(prevProps.filters, this.props.filters)) {
            var filters = this.props.filters || [];
            newState.filters = filters.map(function (filter) {
                return SchemaSieve.flattenSchema(filter);
            });
        }
        if (!isEqual(prevProps.views, this.props.views)) {
            var views = this.props.views || [];
            newState.views = this.flattenViews(views);
        }
        if (!isEmpty(newState)) {
            this.setState(newState);
        }
    };
    Filters.prototype.flattenViews = function (views) {
        return views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.flattenSchema(filter); }) }));
        });
    };
    Filters.prototype.emitViewsUpdate = function () {
        if (!this.props.onViewsUpdate) {
            return;
        }
        this.props.onViewsUpdate(this.state.views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }) }));
        }));
    };
    Filters.prototype.getCleanEditModel = function (field) {
        var schema = this.state.schema;
        if (!field) {
            field = Object.keys(schema.properties).shift();
        }
        var fieldOperators = this.getOperators(field);
        if (!fieldOperators.length) {
            return {
                field: field,
                operator: '',
                value: '',
            };
        }
        var operator = fieldOperators.shift().slug;
        var value = '';
        var subschema = schema.properties[field];
        if (typeof subschema !== 'boolean') {
            if (subschema.enum) {
                value = subschema.enum[0] || '';
            }
            if (subschema.oneOf) {
                value = subschema.oneOf[0].const || '';
            }
            if (subschema.type === 'boolean') {
                value = true;
            }
        }
        return {
            field: field,
            operator: operator,
            value: value,
        };
    };
    Filters.prototype.getOperators = function (field) {
        var schema = this.state.schema;
        return SchemaSieve.getOperators(schema, field);
    };
    Filters.prototype.setEditField = function (field, index) {
        var currentEdit = this.state.edit.slice();
        currentEdit.splice(index, 1, this.getCleanEditModel(field));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.setEditOperator = function (operator, index) {
        var currentEdit = this.state.edit.slice();
        var item = currentEdit[index];
        currentEdit.splice(index, 1, __assign(__assign({}, item), { operator: operator }));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.setEditValue = function (value, index) {
        var currentEdit = this.state.edit.slice();
        var item = currentEdit[index];
        currentEdit.splice(index, 1, __assign(__assign({}, item), { value: value }));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.emitFilterUpdate = function () {
        if (!this.props.onFiltersUpdate) {
            return;
        }
        this.props.onFiltersUpdate(this.state.filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }));
    };
    Filters.prototype.addFilter = function () {
        var _this = this;
        var $id = this.state.editingFilter;
        var schema = this.state.schema;
        var filter = SchemaSieve.createFilter(schema, this.state.edit);
        var currentFilters = this.state.filters;
        var filters;
        if (!!$id) {
            var matchIndex = findIndex(currentFilters, { $id: $id });
            currentFilters.splice(matchIndex, 1, filter);
            filters = currentFilters.slice();
        }
        else {
            filters = currentFilters.concat(filter);
        }
        this.setState({
            filters: filters,
            edit: [this.getCleanEditModel()],
            showModal: false,
            editingFilter: null,
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.editFilter = function (filter) {
        var schema = this.state.schema;
        var signatures = SchemaSieve.decodeFilter(schema, filter);
        this.setState({
            edit: signatures,
            editingFilter: filter.$id,
            showModal: true,
        });
    };
    Filters.prototype.removeFilter = function (_a) {
        var _this = this;
        var $id = _a.$id, title = _a.title;
        this.setState(function (prevState) {
            var newState = __assign(__assign({}, prevState), { filters: reject(prevState.filters, { $id: $id }) });
            if (title === SchemaSieve.FULL_TEXT_SLUG) {
                newState.searchString = '';
            }
            return newState;
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.setFilters = function (filters) {
        var _this = this;
        this.setState({ filters: filters }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.addCompound = function () {
        var _this = this;
        this.setState(function (prevState) { return ({
            edit: prevState.edit.concat(_this.getCleanEditModel()),
        }); });
    };
    Filters.prototype.removeCompound = function (index) {
        var edit = this.state.edit.slice();
        edit.splice(index, 1);
        this.setState({
            edit: edit,
        });
    };
    Filters.prototype.saveView = function (name, scope) {
        var _this = this;
        var view = {
            id: utils.randomString(),
            name: name,
            scope: scope,
            filters: cloneDeep(this.state.filters),
        };
        this.setState(function (prevState) { return ({
            views: prevState.views.concat(view),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    Filters.prototype.deleteView = function (_a) {
        var _this = this;
        var id = _a.id;
        this.setState(function (prevState) { return ({
            views: reject(prevState.views, { id: id }),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    Filters.prototype.setSimpleSearch = function (term) {
        var _this = this;
        this.setState(function (prevState) {
            var newFilters = term
                ? SchemaSieve.upsertFullTextSearch(_this.state.schema, prevState.filters, term)
                : SchemaSieve.removeFullTextSearch(prevState.filters);
            return {
                searchString: term,
                filters: newFilters,
            };
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.shouldRenderComponent = function (mode) {
        if (!this.props.renderMode) {
            return true;
        }
        var allowedModes = castArray(this.props.renderMode);
        if (includes(allowedModes, 'all')) {
            return true;
        }
        return includes(allowedModes, mode);
    };
    Filters.prototype.render = function () {
        var _this = this;
        var filters = this.state.filters;
        return (React.createElement(FilterWrapper, { mb: 3 },
            React.createElement(Flex, { justifyContent: "space-between" },
                this.shouldRenderComponent('add') && (React.createElement(Button, __assign({ mr: 30, disabled: this.props.disabled, primary: true, icon: React.createElement(FaFilter, null), onClick: function () {
                        return _this.setState({ showModal: true, editingFilter: null });
                    } }, this.props.addFilterButtonProps), "Add filter")),
                this.shouldRenderComponent('search') && (React.createElement(SearchWrapper, null,
                    React.createElement(Search, { dark: this.props.dark, disabled: this.props.disabled, value: this.state.searchString, onChange: function (e) {
                            return _this.setSimpleSearch(e.target.value);
                        } }))),
                this.shouldRenderComponent('views') && (React.createElement(ViewsMenu, { dark: this.props.dark, buttonProps: this.props.viewsMenuButtonProps, disabled: this.props.disabled, views: this.state.views || [], schema: this.props.schema, hasMultipleScopes: this.props.viewScopes && this.props.viewScopes.length > 1, setFilters: function (filters) { return _this.setFilters(filters); }, deleteView: function (view) { return _this.deleteView(view); }, renderMode: this.props.renderMode }))),
            this.state.showModal && (React.createElement("div", null,
                React.createElement(Modal, { title: "Filter by", cancel: function () { return _this.setState({ showModal: false }); }, done: function () { return _this.addFilter(); }, action: "Save" },
                    map(this.state.edit, function (_a, index) {
                        var field = _a.field, operator = _a.operator, value = _a.value;
                        var operators = _this.getOperators(field);
                        return (React.createElement(RelativeBox, { key: index },
                            index > 0 && React.createElement(Txt, { my: 2 }, "OR"),
                            React.createElement(Flex, null,
                                React.createElement(Box, { flex: 1 },
                                    React.createElement(Select, { options: map(_this.state.schema.properties, function (s, field) { return ({
                                            field: field,
                                            title: s.title || field,
                                        }); }), valueKey: "field", labelKey: "title", value: _this.state.schema.properties
                                            ? {
                                                field: field,
                                                title: _this.state.schema.properties[field].title || field,
                                            }
                                            : { field: field }, onChange: function (_a) {
                                            var option = _a.option;
                                            return _this.setEditField(option.field, index);
                                        } })),
                                operators.length === 1 && (React.createElement(Txt, { py: 2, px: 3, align: "center" }, operators[0].label)),
                                operators.length > 1 && (React.createElement(Box, { flex: 1, mx: 1 },
                                    React.createElement(Select, { options: operators, valueKey: "slug", labelKey: "label", value: operators.find(function (x) { return x.slug === operator; }), onChange: function (_a) {
                                            var option = _a.option;
                                            return _this.setEditOperator(option.slug, index);
                                        } }))),
                                React.createElement(Box, { flex: 1 },
                                    React.createElement(FilterInput, { operator: operator, value: value, schema: _this.state.schema.properties[field], onUpdate: function (v) { return _this.setEditValue(v, index); } }))),
                            index > 0 && (React.createElement(DeleteButton, { plain: true, fontSize: 1, p: 1, onClick: function () { return _this.removeCompound(index); } },
                                React.createElement(FaClose, null)))));
                    }),
                    React.createElement(Button, { mb: 2, mt: 4, primary: true, underline: true, onClick: function () { return _this.addCompound(); } }, "Add alternative")))),
            this.shouldRenderComponent('summary') &&
                !!filters.length &&
                !this.props.disabled && (React.createElement(Summary, { scopes: this.props.viewScopes, edit: function (filter) { return _this.editFilter(filter); }, delete: function (filter) { return _this.removeFilter(filter); }, saveView: function (name, scope) { return _this.saveView(name, scope); }, clearAllFilters: this.clearAllFilters, filters: filters, views: this.state.views || [], schema: this.state.schema }))));
    };
    return Filters;
}(React.Component));
export default Filters;
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

==> rendition-12.0.0.tgz: package/dist_esm5/components/Filters/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import { faFilter } from '@fortawesome/free-solid-svg-icons/faFilter';
import { faTimes } from '@fortawesome/free-solid-svg-icons/faTimes';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import castArray from 'lodash/castArray';
import cloneDeep from 'lodash/cloneDeep';
import findIndex from 'lodash/findIndex';
import includes from 'lodash/includes';
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import map from 'lodash/map';
import reject from 'lodash/reject';
import * as React from 'react';
import styled from 'styled-components';
import { Button } from '../../';
import * as utils from '../../utils';
import { Box } from '../Box';
import { getDataModel } from '../DataTypes';
import { Flex } from '../Flex';
import Modal from '../Modal';
import Search from '../Search';
import Select from '../Select';
import Txt from '../Txt';
import * as SchemaSieve from './SchemaSieve';
import Summary from './Summary';
import ViewsMenu from './ViewsMenu';
var FilterInput = function (props) {
    var model = getDataModel(props.schema);
    if (!model) {
        return null;
    }
    var Edit = model.Edit;
    return (React.createElement(Edit, { schema: props.schema, value: props.value, operator: props.operator, onUpdate: props.onUpdate, slim: true }));
};
var RelativeBox = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var DeleteButton = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"], ["\n\tcolor: rgba(0, 0, 0, 0.4);\n\tposition: absolute;\n\tbottom: 7px;\n\tright: -35px;\n"])));
var SearchWrapper = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tflex-basis: 500px;\n"], ["\n\tflex-basis: 500px;\n"])));
var FilterWrapper = styled(Box)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var Filters = (function (_super) {
    __extends(Filters, _super);
    function Filters(props) {
        var _this = _super.call(this, props) || this;
        _this.clearAllFilters = function () {
            _this.setFilters([]);
            _this.setState({
                searchString: '',
            });
        };
        var _a = _this.props, _b = _a.filters, filters = _b === void 0 ? [] : _b, schema = _a.schema, _c = _a.views, views = _c === void 0 ? [] : _c;
        var flatSchema = SchemaSieve.flattenSchema(schema);
        var flatViews = _this.flattenViews(views);
        var flatFilters = filters.map(function (filter) {
            return SchemaSieve.flattenSchema(filter);
        });
        _this.state = {
            showModal: false,
            searchString: '',
            editingFilter: null,
            filters: flatFilters,
            views: flatViews,
            schema: flatSchema,
            edit: [],
        };
        _this.state.edit.push(_this.getCleanEditModel());
        return _this;
    }
    Filters.prototype.componentDidUpdate = function (prevProps) {
        var newState = {};
        if (!isEqual(prevProps.schema, this.props.schema)) {
            newState.schema = SchemaSieve.flattenSchema(this.props.schema);
        }
        if (!isEqual(prevProps.filters, this.props.filters)) {
            var filters = this.props.filters || [];
            newState.filters = filters.map(function (filter) {
                return SchemaSieve.flattenSchema(filter);
            });
        }
        if (!isEqual(prevProps.views, this.props.views)) {
            var views = this.props.views || [];
            newState.views = this.flattenViews(views);
        }
        if (!isEmpty(newState)) {
            this.setState(newState);
        }
    };
    Filters.prototype.flattenViews = function (views) {
        return views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.flattenSchema(filter); }) }));
        });
    };
    Filters.prototype.emitViewsUpdate = function () {
        if (!this.props.onViewsUpdate) {
            return;
        }
        this.props.onViewsUpdate(this.state.views.map(function (_a) {
            var filters = _a.filters, view = __rest(_a, ["filters"]);
            return (__assign(__assign({}, view), { filters: filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }) }));
        }));
    };
    Filters.prototype.getCleanEditModel = function (field) {
        var schema = this.state.schema;
        if (!field) {
            field = Object.keys(schema.properties).shift();
        }
        var fieldOperators = this.getOperators(field);
        if (!fieldOperators.length) {
            return {
                field: field,
                operator: '',
                value: '',
            };
        }
        var operator = fieldOperators.shift().slug;
        var value = '';
        var subschema = schema.properties[field];
        if (typeof subschema !== 'boolean') {
            if (subschema.enum) {
                value = subschema.enum[0] || '';
            }
            if (subschema.oneOf) {
                value = subschema.oneOf[0].const || '';
            }
            if (subschema.type === 'boolean') {
                value = true;
            }
        }
        return {
            field: field,
            operator: operator,
            value: value,
        };
    };
    Filters.prototype.getOperators = function (field) {
        var schema = this.state.schema;
        return SchemaSieve.getOperators(schema, field);
    };
    Filters.prototype.setEditField = function (field, index) {
        var currentEdit = this.state.edit.slice();
        currentEdit.splice(index, 1, this.getCleanEditModel(field));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.setEditOperator = function (operator, index) {
        var currentEdit = this.state.edit.slice();
        var item = currentEdit[index];
        currentEdit.splice(index, 1, __assign(__assign({}, item), { operator: operator }));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.setEditValue = function (value, index) {
        var currentEdit = this.state.edit.slice();
        var item = currentEdit[index];
        currentEdit.splice(index, 1, __assign(__assign({}, item), { value: value }));
        this.setState({
            edit: currentEdit,
        });
    };
    Filters.prototype.emitFilterUpdate = function () {
        if (!this.props.onFiltersUpdate) {
            return;
        }
        this.props.onFiltersUpdate(this.state.filters.map(function (filter) { return SchemaSieve.unflattenSchema(filter); }));
    };
    Filters.prototype.addFilter = function () {
        var _this = this;
        var $id = this.state.editingFilter;
        var schema = this.state.schema;
        var filter = SchemaSieve.createFilter(schema, this.state.edit);
        var currentFilters = this.state.filters;
        var filters;
        if (!!$id) {
            var matchIndex = findIndex(currentFilters, { $id: $id });
            currentFilters.splice(matchIndex, 1, filter);
            filters = currentFilters.slice();
        }
        else {
            filters = currentFilters.concat(filter);
        }
        this.setState({
            filters: filters,
            edit: [this.getCleanEditModel()],
            showModal: false,
            editingFilter: null,
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.editFilter = function (filter) {
        var schema = this.state.schema;
        var signatures = SchemaSieve.decodeFilter(schema, filter);
        this.setState({
            edit: signatures,
            editingFilter: filter.$id,
            showModal: true,
        });
    };
    Filters.prototype.removeFilter = function (_a) {
        var _this = this;
        var $id = _a.$id, title = _a.title;
        this.setState(function (prevState) {
            var newState = __assign(__assign({}, prevState), { filters: reject(prevState.filters, { $id: $id }) });
            if (title === SchemaSieve.FULL_TEXT_SLUG) {
                newState.searchString = '';
            }
            return newState;
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.setFilters = function (filters) {
        var _this = this;
        this.setState({ filters: filters }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.addCompound = function () {
        var _this = this;
        this.setState(function (prevState) { return ({
            edit: prevState.edit.concat(_this.getCleanEditModel()),
        }); });
    };
    Filters.prototype.removeCompound = function (index) {
        var edit = this.state.edit.slice();
        edit.splice(index, 1);
        this.setState({
            edit: edit,
        });
    };
    Filters.prototype.saveView = function (name, scope) {
        var _this = this;
        var view = {
            id: utils.randomString(),
            name: name,
            scope: scope,
            filters: cloneDeep(this.state.filters),
        };
        this.setState(function (prevState) { return ({
            views: prevState.views.concat(view),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    Filters.prototype.deleteView = function (_a) {
        var _this = this;
        var id = _a.id;
        this.setState(function (prevState) { return ({
            views: reject(prevState.views, { id: id }),
        }); }, function () {
            return _this.props.onViewsUpdate && _this.props.onViewsUpdate(_this.state.views);
        });
    };
    Filters.prototype.setSimpleSearch = function (term) {
        var _this = this;
        this.setState(function (prevState) {
            var newFilters = term
                ? SchemaSieve.upsertFullTextSearch(_this.state.schema, prevState.filters, term)
                : SchemaSieve.removeFullTextSearch(prevState.filters);
            return {
                searchString: term,
                filters: newFilters,
            };
        }, function () { return _this.emitFilterUpdate(); });
    };
    Filters.prototype.shouldRenderComponent = function (mode) {
        if (!this.props.renderMode) {
            return true;
        }
        var allowedModes = castArray(this.props.renderMode);
        if (includes(allowedModes, 'all')) {
            return true;
        }
        return includes(allowedModes, mode);
    };
    Filters.prototype.render = function () {
        var _this = this;
        var filters = this.state.filters;
        return (React.createElement(FilterWrapper, { mb: 3 },
            React.createElement(Flex, { justifyContent: "space-between" },
                this.shouldRenderComponent('add') && (React.createElement(Button, __assign({ mr: 30, disabled: this.props.disabled, primary: true, icon: React.createElement(FontAwesomeIcon, { icon: faFilter }), onClick: function () {
                        return _this.setState({ showModal: true, editingFilter: null });
                    } }, this.props.addFilterButtonProps), "Add filter")),
                this.shouldRenderComponent('search') && (React.createElement(SearchWrapper, null,
                    React.createElement(Search, { dark: this.props.dark, disabled: this.props.disabled, value: this.state.searchString, onChange: function (e) {
                            return _this.setSimpleSearch(e.target.value);
                        } }))),
                this.shouldRenderComponent('views') && (React.createElement(ViewsMenu, { dark: this.props.dark, buttonProps: this.props.viewsMenuButtonProps, disabled: this.props.disabled, views: this.state.views || [], schema: this.props.schema, hasMultipleScopes: this.props.viewScopes && this.props.viewScopes.length > 1, setFilters: function (filters) { return _this.setFilters(filters); }, deleteView: function (view) { return _this.deleteView(view); }, renderMode: this.props.renderMode }))),
            this.state.showModal && (React.createElement("div", null,
                React.createElement(Modal, { title: "Filter by", cancel: function () { return _this.setState({ showModal: false }); }, done: function () { return _this.addFilter(); }, action: "Save" },
                    map(this.state.edit, function (_a, index) {
                        var field = _a.field, operator = _a.operator, value = _a.value;
                        var operators = _this.getOperators(field);
                        return (React.createElement(RelativeBox, { key: index },
                            index > 0 && React.createElement(Txt, { my: 2 }, "OR"),
                            React.createElement(Flex, null,
                                React.createElement(Box, { flex: 1 },
                                    React.createElement(Select, { options: map(_this.state.schema.properties, function (s, field) { return ({
                                            field: field,
                                            title: s.title || field,
                                        }); }), valueKey: "field", labelKey: "title", value: _this.state.schema.properties
                                            ? {
                                                field: field,
                                                title: _this.state.schema.properties[field].title || field,
                                            }
                                            : { field: field }, onChange: function (_a) {
                                            var option = _a.option;
                                            return _this.setEditField(option.field, index);
                                        } })),
                                operators.length === 1 && (React.createElement(Txt, { py: 2, px: 3, align: "center" }, operators[0].label)),
                                operators.length > 1 && (React.createElement(Box, { flex: 1, mx: 1 },
                                    React.createElement(Select, { options: operators, valueKey: "slug", labelKey: "label", value: operators.find(function (x) { return x.slug === operator; }), onChange: function (_a) {
                                            var option = _a.option;
                                            return _this.setEditOperator(option.slug, index);
                                        } }))),
                                React.createElement(Box, { flex: 1 },
                                    React.createElement(FilterInput, { operator: operator, value: value, schema: _this.state.schema.properties[field], onUpdate: function (v) { return _this.setEditValue(v, index); } }))),
                            index > 0 && (React.createElement(DeleteButton, { plain: true, fontSize: 1, p: 1, onClick: function () { return _this.removeCompound(index); } },
                                React.createElement(FontAwesomeIcon, { icon: faTimes })))));
                    }),
                    React.createElement(Button, { mb: 2, mt: 4, primary: true, underline: true, onClick: function () { return _this.addCompound(); } }, "Add alternative")))),
            this.shouldRenderComponent('summary') &&
                !!filters.length &&
                !this.props.disabled && (React.createElement(Summary, { scopes: this.props.viewScopes, edit: function (filter) { return _this.editFilter(filter); }, delete: function (filter) { return _this.removeFilter(filter); }, saveView: function (name, scope) { return _this.saveView(name, scope); }, clearAllFilters: this.clearAllFilters, filters: filters, views: this.state.views || [], schema: this.state.schema }))));
    };
    return Filters;
}(React.Component));
export default Filters;
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;
